@@ -1,8 +1,8 @@
-package Pcore::Captcha v0.6.3;
+package Pcore::Captcha v0.7.0;
 
 use Pcore -dist, -class;
 
-extends qw[Pcore::API::Response];
+with qw[Pcore::Util::Status::Role];
 
 has captcha => ( is => 'ro', isa => ScalarRef, required => 1 );
 
